searchNodes=[{"doc":"Elixir IP value tool suite. Erlang provides a structured IP type, but the tooling around it is very squirelly, spread out over several disjoint modules, and not ergonomic with respect to structured programming. Elixir gives us some better tools (like protocols and guards). This module, and its related modules IP.Range and IP.Subnet provide a better view into operator-friendly, composable programming that interfaces well with erlang IP primitives.","ref":"IP.html","title":"IP","type":"module"},{"doc":"Finds an ip address in a string, returning an ok or error tuple on failure.","ref":"IP.html#from_string/1","title":"IP.from_string/1","type":"function"},{"doc":"Converts an ip address from a string. iex&gt; IP.from_string!(&quot;255.255.255.255&quot;) {255, 255, 255, 255}","ref":"IP.html#from_string!/1","title":"IP.from_string!/1","type":"function"},{"doc":"true if the argument is either ipv6 or ipv4 datatype usable in guards. iex&gt; IP.is_ip({0, 0, 0, 0, 0, 0, 0, 1}) true iex&gt; IP.is_ip({127, 0, 0, 1}) true","ref":"IP.html#is_ip/1","title":"IP.is_ip/1","type":"macro"},{"doc":"true if the argument is an ipv4 datatype usable in guards. iex&gt; IP.is_ipv4({10, 0, 0, 1}) true iex&gt; IP.is_ipv4(:foo) false iex&gt; IP.is_ipv4({256, 0, 0, 0}) false","ref":"IP.html#is_ipv4/1","title":"IP.is_ipv4/1","type":"macro"},{"doc":"true if the argument is an ipv6 datatype usable in guards. iex&gt; IP.is_ipv6({0, 0, 0, 0, 0, 0, 0, 1}) true iex&gt; IP.is_ipv6(:foo) false iex&gt; IP.is_ipv6({0x10000, 0, 0, 0, 0, 0, 0, 1}) false","ref":"IP.html#is_ipv6/1","title":"IP.is_ipv6/1","type":"macro"},{"doc":"returns the canonical ip address of localhost. Defaults to ipv4. iex&gt; IP.localhost() {127, 0, 0, 1} iex&gt; IP.localhost(:v6) {0, 0, 0, 0, 0, 0, 0, 1}","ref":"IP.html#localhost/1","title":"IP.localhost/1","type":"function"},{"doc":"generates an ip mask with specified bit_length. Can also generate raw integer or raw binary forms. Defaults to IPv4. iex&gt; IP.mask(32, :v4_int) 0xFFFF_FFFF iex&gt; IP.mask(32, :v4_bin) &lt;&lt;255, 255, 255, 255&gt;&gt; iex&gt; IP.mask(32, :v4) {255, 255, 255, 255} iex&gt; IP.mask(24, :v4) {255, 255, 255, 0} iex&gt; IP.mask(0) {0, 0, 0, 0} iex&gt; IP.mask(128, :v6) {0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF, 0xFFFF} iex&gt; IP.mask(0, :v6) {0, 0, 0, 0, 0, 0, 0, 0}","ref":"IP.html#mask/2","title":"IP.mask/2","type":"function"},{"doc":"returns the next ip address. iex&gt; IP.next({10, 0, 0, 255}) {10, 0, 1, 0} iex&gt; IP.next({0, 0, 0, 0, 0, 0, 0, 0xFFFF}) {0, 0, 0, 0, 0, 0, 1, 0}","ref":"IP.html#next/1","title":"IP.next/1","type":"function"},{"doc":"generates an the subnet prefix for a given ip address. iex&gt; IP.prefix({10, 0, 1, 23}, 24) {10, 0, 1, 0}","ref":"IP.html#prefix/2","title":"IP.prefix/2","type":"function"},{"doc":"returns the previous ip address. iex&gt; IP.prev({10, 0, 1, 0}) {10, 0, 0, 255} iex&gt; IP.prev({0, 0, 0, 0, 0, 0, 1, 0}) {0, 0, 0, 0, 0, 0, 0, 0xFFFF}","ref":"IP.html#prev/1","title":"IP.prev/1","type":"function"},{"doc":"picks a random ip address from a range or a subnet. You may exclude individual ip addresses, ranges, or subnets to the excludes parameter and they won&#39;t be picked. Note that subnets will pick the prefix and broadcast addresses, if you would like to exclude those, you must add them explicitly to the excludes parameter. Warning: this algorithm is rather bad, so use only with blocks of less than about 1024.","ref":"IP.html#random/2","title":"IP.random/2","type":"function"},{"doc":"allows you to use the convenient ~i sigil to declare an IP address in its normal string form, instead of using the tuple form. iex&gt; import IP iex&gt; ~i&quot;10.0.0.1&quot; {10, 0, 0, 1} also works for cidr-form subnet blocks iex&gt; import IP iex&gt; ~i&quot;10.0.0.0/24&quot; %IP.Subnet{routing_prefix: {10, 0, 0, 0}, bit_length: 24} and generic IP ranges iex&gt; import IP iex&gt; ~i&quot;10.0.0.3..10.0.0.7&quot; %IP.Range{first: {10, 0, 0, 3}, last: {10, 0, 0, 7}} and socket addresses: iex&gt; import IP iex&gt; ~i&quot;10.0.0.1:1234&quot; %IP.SockAddr{family: :inet, port: 1234, addr: {10, 0, 0, 1}} You can also use ~i for ip addresses and subnets with the m suffix in the context of matches. Example: ~i&quot;10.0.x.3&quot;m = {10, 0, 1, 3} # =&gt; matches x to 1","ref":"IP.html#sigil_i/2","title":"IP.sigil_i/2","type":"macro"},{"doc":"Converts an ip address to a string. For some situations, like converting an ip address to a hostname you might want hyphens as delimiters instead, in which case you should pass :hyphens as the :style term. Also takes, nil, in which case it emits an empty string. iex&gt; IP.to_string({255, 255, 255, 255}) &quot;255.255.255.255&quot; iex&gt; IP.to_string({255, 255, 255, 255}, :hyphens) &quot;255-255-255-255&quot; iex&gt; IP.to_string({0, 0, 0, 0, 0, 0, 0, 1}) &quot;::1&quot;","ref":"IP.html#to_string/2","title":"IP.to_string/2","type":"function"},{"doc":"any ip address, either v4 or v6","ref":"IP.html#t:addr/0","title":"IP.addr/0","type":"type"},{"doc":"16-bit integers","ref":"IP.html#t:short/0","title":"IP.short/0","type":"type"},{"doc":"ipv4 representation in erlang.","ref":"IP.html#t:v4/0","title":"IP.v4/0","type":"type"},{"doc":"ipv6 representation in erlang.","ref":"IP.html#t:v6/0","title":"IP.v6/0","type":"type"},{"doc":"Convenience type which encapsulates the idea of a contiguous range of IP addresses. NB The distinction between an IP.Range and an IP.Subnet is that a Subnet must have its bounds at certain powers-of-two and multiple thereof that are governed by the subnet bit-length. A range is not constrained and is a simple &quot;dumb list of ip addresses&quot;. Typically ranges will be proper subsets of Subnets. Enumerable Implements the Enumerable protocol, so the following sorts of things are possible: iex&gt; import IP iex&gt; Enum.map(~i&quot;10.0.0.3..10.0.0.5&quot;, &amp;IP.to_string/1) [&quot;10.0.0.3&quot;, &quot;10.0.0.4&quot;, &quot;10.0.0.5&quot;]","ref":"IP.Range.html","title":"IP.Range","type":"module"},{"doc":"Finds an ip range in a string, returning an ok or error tuple on failure.","ref":"IP.Range.html#from_string/1","title":"IP.Range.from_string/1","type":"function"},{"doc":"converts a string to an ip range. The delimiter must be &quot;..&quot;, as this is compatible with both ipv4 and ipv6 addresses checks if the range is well-ordered. iex&gt; import IP iex&gt; IP.Range.from_string!(&quot;10.0.0.3..10.0.0.5&quot;) %IP.Range{ first: {10, 0, 0, 3}, last: {10, 0, 0, 5} }","ref":"IP.Range.html#from_string!/1","title":"IP.Range.from_string!/1","type":"function"},{"doc":"true if the argument is an proper ip range checks if the range is well-ordered. usable in guards. iex&gt; import IP iex&gt; IP.Range.is_range(~i&quot;10.0.0.1..10.0.0.3&quot;) true iex&gt; IP.Range.is_range(:foo) false iex&gt; IP.Range.is_range(%IP.Range{first: ~i&quot;10.0.0.3&quot;, last: ~i&quot;10.0.0.1&quot;}) false","ref":"IP.Range.html#is_range/1","title":"IP.Range.is_range/1","type":"macro"},{"doc":"Creates a new IP range, with validation. If your provide an out-of-order range, it will raise ArgumentError. iex&gt; IP.Range.new({10, 0, 0, 1}, {10, 0, 0, 5}) %IP.Range{ first: {10, 0, 0, 1}, last: {10, 0, 0, 5} }","ref":"IP.Range.html#new/2","title":"IP.Range.new/2","type":"function"},{"doc":"converts a ip range to a string with delimiter &quot;..&quot; checks if the range is well-ordered. iex&gt; IP.Range.to_string(%IP.Range{first: {10, 0, 0, 3},last: {10, 0, 0, 5}}) &quot;10.0.0.3..10.0.0.5&quot;","ref":"IP.Range.html#to_string/1","title":"IP.Range.to_string/1","type":"function"},{"doc":"generic ip range","ref":"IP.Range.html#t:t/0","title":"IP.Range.t/0","type":"type"},{"doc":"ip ranges typed to either ipv4 or ipv6","ref":"IP.Range.html#t:t/1","title":"IP.Range.t/1","type":"type"},{"doc":"Tools for handling the t::socket.sockaddr_in4/0 type. Unless you&#39;re using the :socket library, for low level socket access you probably won&#39;t need this module! Support for inet6 forthcoming.","ref":"IP.SockAddr.html","title":"IP.SockAddr","type":"module"},{"doc":"Like from_string/1, but returns an ok or error tuple on failure.","ref":"IP.SockAddr.html#from_string/1","title":"IP.SockAddr.from_string/1","type":"function"},{"doc":"Creates an elixir struct, which is compatible with :socket module&#39;s sockaddr_in4 type. You may pass this, for example to :socket.bind/2","ref":"IP.SockAddr.html#from_string!/1","title":"IP.SockAddr.from_string!/1","type":"function"},{"doc":"converts a t::socket.sockaddr_in4 value to Compatible with sockaddr maps returned by the socket library, not selective on the IP.SockAddr struct.","ref":"IP.SockAddr.html#to_string/1","title":"IP.SockAddr.to_string/1","type":"function"},{"doc":"","ref":"IP.SockAddr.html#t:t/0","title":"IP.SockAddr.t/0","type":"type"},{"doc":"Convenience type which encapsulates the idea of an IP subnet. See: https://en.wikipedia.org/wiki/Subnetwork NB The distinction between an IP.Range and an IP.Subnet is that a Subnet must have its bounds at certain powers-of-two and multiple thereof that are governed by the subnet bit-length. A range is not constrained and is a simple &quot;dumb list of ip addresses&quot;. Typically ranges will be proper subsets of Subnets. Enumerable Implements the Enumerable protocol, so the following sorts of things are possible: iex&gt; import IP iex&gt; Enum.map(~i&quot;10.0.0.4/30&quot;, &amp;IP.to_string/1) [&quot;10.0.0.4&quot;, &quot;10.0.0.5&quot;, &quot;10.0.0.6&quot;, &quot;10.0.0.7&quot;]","ref":"IP.Subnet.html","title":"IP.Subnet","type":"module"},{"doc":"retrieves the bitlength from a subnet. iex&gt; import IP iex&gt; IP.Subnet.bitlength(~i&quot;10.0.0.0/24&quot;) 24","ref":"IP.Subnet.html#bitlength/1","title":"IP.Subnet.bitlength/1","type":"function"},{"doc":"finds the broadcast address for a subnet iex&gt; import IP iex&gt; IP.Subnet.broadcast(~i&quot;10.0.0.0/23&quot;) {10, 0, 1, 255}","ref":"IP.Subnet.html#broadcast/1","title":"IP.Subnet.broadcast/1","type":"function"},{"doc":"Finds an ip subnet in a string, returning an ok or error tuple on failure.","ref":"IP.Subnet.html#from_string/1","title":"IP.Subnet.from_string/1","type":"function"},{"doc":"converts a string to an ip subnet. The delimiter must be &quot;..&quot;, as this is compatible with both ipv4 and ipv6 addresses checks if the values are sensible. iex&gt; import IP iex&gt; IP.Subnet.from_string!(&quot;10.0.0.0/24&quot;) %IP.Subnet{ routing_prefix: {10, 0, 0, 0}, bit_length: 24 }","ref":"IP.Subnet.html#from_string!/1","title":"IP.Subnet.from_string!/1","type":"function"},{"doc":"true if the term is a subnet struct, and it&#39;s valid. usable in guards. iex&gt; import IP iex&gt; IP.Subnet.is_subnet(~i&quot;10.0.0.0/32&quot;) true iex&gt; IP.Subnet.is_subnet(:foo) false iex&gt; IP.Subnet.is_subnet(%IP.Subnet{routing_prefix: {10, 0, 0, 0}, bit_length: 33}) false","ref":"IP.Subnet.html#is_subnet/1","title":"IP.Subnet.is_subnet/1","type":"macro"},{"doc":"computes the netmask for a subnet. iex&gt; import IP iex&gt; IP.Subnet.netmask(~i&quot;10.0.0.0/24&quot;) {255, 255, 255, 0}","ref":"IP.Subnet.html#netmask/1","title":"IP.Subnet.netmask/1","type":"function"},{"doc":"creates a new IP Subnet struct from a routing prefix and bit length. The routing prefix must be an actual routing prefix for the bit length, otherwise it will raise ArgumentError. If you are attempting to find the subnet for a given ip address, use of/2","ref":"IP.Subnet.html#new/2","title":"IP.Subnet.new/2","type":"function"},{"doc":"creates a corresponding IP subnet associated with a given IP address and bit length.","ref":"IP.Subnet.html#of/2","title":"IP.Subnet.of/2","type":"function"},{"doc":"retrieves the routing prefix from a subnet. iex&gt; import IP iex&gt; IP.Subnet.prefix(~i&quot;10.0.0.0/24&quot;) {10, 0, 0, 0}","ref":"IP.Subnet.html#prefix/1","title":"IP.Subnet.prefix/1","type":"function"},{"doc":"converts an ip subnet to standard CIDR-form, with a slash delimiter. iex&gt; IP.Subnet.to_string(%IP.Subnet{routing_prefix: {10, 0, 0, 0}, bit_length: 24}) &quot;10.0.0.0/24&quot;","ref":"IP.Subnet.html#to_string/1","title":"IP.Subnet.to_string/1","type":"function"},{"doc":"generic ip subnet","ref":"IP.Subnet.html#t:t/0","title":"IP.Subnet.t/0","type":"type"},{"doc":"ip subnet typed to ipv4 or ipv6","ref":"IP.Subnet.html#t:t/1","title":"IP.Subnet.t/1","type":"type"},{"doc":"Mac Address value tool module.","ref":"Mac.html","title":"Mac","type":"module"},{"doc":"converts a mac address string and turns it into a proper mac address datatype. Supports standard colon format, BMC hyphen format, and arista/cisco switch dot format. iex&gt; Mac.from_string!(&quot;06:AA:07:FB:B6:1E&quot;) {0x06, 0xAA, 0x07, 0xFB, 0xB6, 0x1E} iex&gt; Mac.from_string!(&quot;06:aa:07:fb:b6:1e&quot;) {0x06, 0xAA, 0x07, 0xFB, 0xB6, 0x1E} iex&gt; Mac.from_string!(&quot;06-AA-07-FB-B6-1E&quot;) {0x06, 0xAA, 0x07, 0xFB, 0xB6, 0x1E} iex&gt; Mac.from_string!(&quot;06aa.07fb.b61e&quot;) {0x06, 0xAA, 0x07, 0xFB, 0xB6, 0x1E}","ref":"Mac.html#from_string/1","title":"Mac.from_string/1","type":"function"},{"doc":"","ref":"Mac.html#from_string!/1","title":"Mac.from_string!/1","type":"function"},{"doc":"checks to see if a value is a local mac address, by convention it means it has been assigned by a VM system. usable in guards. iex&gt; Mac.is_local_mac({0xF2, 0, 0, 1, 1, 1}) true iex&gt; Mac.is_local_mac({0xF0, 0, 0, 1, 1, 1}) false","ref":"Mac.html#is_local_mac/1","title":"Mac.is_local_mac/1","type":"macro"},{"doc":"checks to see if a value is a mac address. usable in guards. iex&gt; Mac.is_mac({10, 0, 0, 1, 1, 1}) true iex&gt; Mac.is_mac(:foo) false iex&gt; Mac.is_mac({0x100, 0, 0, 1, 1, 1}) false iex&gt; Mac.is_mac({10, 0, 0, 1, 1, 1, 1}) false","ref":"Mac.html#is_mac/1","title":"Mac.is_mac/1","type":"macro"},{"doc":"checks to see if a value is a local mac address, by convention it means it has been assigned by the hardware manufacturer usable in guards. iex&gt; Mac.is_universal_mac({0xF2, 0, 0, 1, 1, 1}) false iex&gt; Mac.is_universal_mac({0xF0, 0, 0, 1, 1, 1}) true","ref":"Mac.html#is_universal_mac/1","title":"Mac.is_universal_mac/1","type":"macro"},{"doc":"generates a mask for the first n bits of the mac address. iex&gt; Mac.mask(1) {0x80, 0, 0, 0, 0, 0} iex&gt; Mac.mask(16) {0xFF, 0xFF, 0, 0, 0, 0} you may pass another mode to the second parameter for other formats. iex&gt; Mac.mask(16, :binary) &lt;&lt;0xFF, 0xFF, 0, 0, 0, 0&gt;&gt; iex&gt; Mac.mask(16, :integer) 0xFFFF_0000_0000","ref":"Mac.html#mask/2","title":"Mac.mask/2","type":"function"},{"doc":"generates a random mac address from another, with a mask value","ref":"Mac.html#random/2","title":"Mac.random/2","type":"function"},{"doc":"allows you to use the convenient ~m sigil to declare a Mac address in its normal string form, instead of using the tuple form. iex&gt; import Mac iex&gt; ~m&quot;06:66:F4:12:34:56&quot; {0x06, 0x66, 0xF4, 0x12, 0x34, 0x56}","ref":"Mac.html#sigil_m/2","title":"Mac.sigil_m/2","type":"macro"},{"doc":"Converts a mac address to a string iex&gt; Mac.to_string({255, 255, 255, 255, 255, 255}) &quot;FF:FF:FF:FF:FF:FF&quot; iex&gt; Mac.to_string({6, 1, 2, 3, 4, 5}) &quot;06:01:02:03:04:05&quot;","ref":"Mac.html#to_string/1","title":"Mac.to_string/1","type":"function"},{"doc":"general mac addresses are six octets.","ref":"Mac.html#t:t/0","title":"Mac.t/0","type":"type"}]